@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.101-8-g95616de
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.102-14-gb7ccdb2
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 use Moose;
 with
@@ -65,7 +65,7 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    _uniq($self->$orig(@_), qw(LICENCE LICENSE CONTRIBUTING Changes ppport.h INSTALL));
+    sort(_uniq($self->$orig(@_), $self->licence, qw(CONTRIBUTING Changes ppport.h INSTALL)));
 };
 
 has changes_version_columns => (
@@ -221,7 +221,7 @@ sub configure
         [ 'Test::MinimumVersion' => { ':version' => '2.000003', max_target_perl => '5.006' } ],
         'PodSyntaxTests',
         'PodCoverageTests',
-        [ 'Test::PodSpelling'   => { ':version' => '2.006001' } ],
+        [ 'Test::PodSpelling'   => { ':version' => '2.006001', stopwords => ['irc'] } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
         [ 'Test::Pod::No404s'   => { ':version' => '1.002' } ],
         [ 'Test::Kwalitee'      => { ':version' => '2.06', filename => 'xt/author/kwalitee.t' } ],
@@ -244,7 +244,6 @@ sub configure
                 post_code_replacer => 'replace_with_nothing',
             }
         ],
-        [ 'ReadmeAnyFromPod'    => { ':version' => '0.142180', type => 'pod', location => 'root', phase => 'release' } ],
 
         # Metadata
         $self->server eq 'github' ? [ 'GithubMeta' => { ':version' => '0.54', homepage => 0, issues => 0 } ] : (),
@@ -265,7 +264,7 @@ sub configure
 
         # Register Prereqs
         # (MakeMaker or other installer)
-        'AutoPrereqs',
+        [ 'AutoPrereqs'         => { ':version' => '5.038' } ],
         'Prereqs::AuthorDeps',
         [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
         [ 'Prereqs' => pluginbundle_version => {
@@ -321,7 +320,9 @@ sub configure
             [ 'Run::AfterRelease' => 'remove old READMEs' => { ':version' => '0.038', quiet => 1, eval => q!unlink 'README.md'! } ]
             : ()),
         [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
-        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } _uniq('README.md', 'README.pod', $self->copy_files_from_release) ], commit_msg => '%N-%v%t%n%n%c' } ],
+        [ 'ReadmeAnyFromPod'    => { ':version' => '0.142180', type => 'pod', location => 'root', phase => 'release' } ],
+
+        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } sort(_uniq('README.md', 'README.pod', $self->copy_files_from_release)) ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
 
@@ -443,7 +444,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 SYNOPSIS
 
@@ -580,12 +581,6 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     replacer = replace_with_comment
     post_code_replacer = replace_with_nothing
 
-    [ReadmeAnyFromPod]
-    :version = 0.142180
-    type = pod
-    location = root
-    phase = release
-
 
     ;;; Metadata
     [GithubMeta]    ; (if server = 'github' or omitted)
@@ -634,6 +629,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     ;;; Register Prereqs
     [AutoPrereqs]
+    :version = 5.038
     [Prereqs::AuthorDeps]
     [MinimumPerl]
     :version = 1.006
@@ -732,6 +728,12 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     filename = LICENSE
     filename = ppport.h
 
+    [ReadmeAnyFromPod]
+    :version = 0.142180
+    type = pod
+    location = root
+    phase = release
+
     [Git::Commit / release snapshot]
     :version = 2.020
     add_files_in = .
@@ -842,15 +844,29 @@ plugin(s).
 
 Encouraged choices are:
 
-    installer = ModuleBuildTiny
+=over 4
 
-    installer = MakeMaker
+=item *
 
-    installer = MakeMaker::Fallback (when used in combination with ModuleBuildTiny)
+C<< installer = ModuleBuildTiny >>
 
-    installer = =inc::Foo (if no configs are needed for this plugin; e.g. subclassed from L<[MakeMaker::Awesome]|Dist::Zilla::Plugin::MakeMaker::Awesome>)
+=item *
 
-    installer = none (if you are including your own later on, with configs)
+C<< installer = MakeMaker >>
+
+=item *
+
+C<< installer = MakeMaker::Fallback >> (when used in combination with ModuleBuildTiny)
+
+=item *
+
+C<< installer = =inc::Foo >> (if no configs are needed for this plugin; e.g. subclassed from L<[MakeMaker::Awesome]|Dist::Zilla::Plugin::MakeMaker::Awesome>)
+
+=item *
+
+C<< installer = none >> (if you are including your own later on, with configs)
+
+=back
 
 =head2 server
 
@@ -984,10 +1000,15 @@ L<Dist::Zilla::MintingProfile::Author::ETHER>
 
 =head1 SUPPORT
 
-=for stopwords irc
-
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-Author-ETHER>
 (or L<bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org|mailto:bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+http://dzil.org/#mailing-list.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 =head1 AUTHOR
