@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
@@ -47,6 +47,39 @@ sub configure
         [ 'Collect' => 'TYPES'      => { command => 'type' } ],
         'Leftovers',
         [ 'Region' => 'postlude' ],
+
+        [ 'GenerateSection' => 'generate SUPPORT' => {
+                title => 'SUPPORT',
+                main_module_only => 0,
+                text => [ <<'SUPPORT',
+{{ join("\n\n",
+    ($bugtracker_email && $bugtracker_email =~ /rt\.cpan\.org/)
+    ? "Bugs may be submitted through L<the RT bug tracker|$bugtracker_web>\n(or L<$bugtracker_email|mailto:$bugtracker_email>)."
+    : $bugtracker_web
+    ? "bugs may be submitted through L<$bugtracker_web>."
+    : (),
+
+    $distmeta->{resources}{x_MailingList} ? 'There is also a mailing list available for users of this distribution, at' . "\n" . $distmeta->{resources}{x_MailingList} . '.' : (),
+
+    $distmeta->{resources}{x_IRC}
+        ? 'There is also an irc channel available for users of this distribution, at' . "\n" . $distmeta->{resources}{x_IRC} . '.'
+        : (),
+
+    ($distmeta->{x_authority} // '') eq 'cpan:ETHER'
+    ? "I am also usually active on irc, as 'ether' at C<irc.perl.org>."
+    : (),
+) }}
+SUPPORT
+                        ] },
+        ],
+
+        [ 'AllowOverride' => 'allow override SUPPORT' => {
+               header_re => '^SUPPORT',
+               action => 'prepend',
+               match_anywhere => 0,
+            },
+        ],
+
         'Authors',
         [ 'Contributors' => { ':version' => '0.008' } ],
         [ 'Legal' => { ':version' => '4.011', header => 'COPYRIGHT AND ' . $licence_filename } ],
@@ -134,7 +167,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 SYNOPSIS
 
@@ -195,6 +228,14 @@ following F<weaver.ini>, minus some optimizations:
 
     [Region / postlude]
 
+    [GenerateSection / SUPPORT]
+    main_module_only = 0
+    text = <template>
+    [AllowOverride / allow override SUPPORT]
+    header_re = ^SUPPORT
+    action = prepend
+    match_anywhere = 0
+
     [Authors]
     [Contributors]
     :version = 0.008
@@ -209,6 +250,8 @@ This is also equivalent (other than section ordering) to:
 
     [-Transformer / List]
     transformer = List
+    [-Transformer / Verbatim]
+    transformer = Verbatim
 
     [Region / header]
     [@Default]
@@ -216,16 +259,33 @@ This is also equivalent (other than section ordering) to:
     [Collect / TYPES]
     command = type
 
+    [GenerateSection / generate SUPPORT]
+    main_module_only = 0
+    text = <template>
+    [AllowOverride / allow override SUPPORT]
+    header_re = ^SUPPORT
+    action = prepend
+    match_anywhere = 0
+
     [Contributors]
     :version = 0.008
 
     [Region / footer]
 
-=head1 OPTIONS / OVERRIDES
+=head1 OPTIONS
 
 None at this time. (The bundle is never instantiated, so this doesn't seem to
 be possible without updates to L<Pod::Weaver>.)
 
+=head1 OVERRIDING A SPECIFIC SECTION
+
+This F<weaver.ini> will let you use a custom C<COPYRIGHT AND LICENCE> section and still use the plugin bundle:
+
+    [@Author::ETHER]
+    [AllowOverride / OverrideLegal]
+    header_re = ^COPYRIGHT
+    match_anywhere = 1
+
 =head1 ADDING STOPWORDS FOR SPELLING TESTS
 
 As noted in L<Dist::Zilla::PluginBundle::Author::ETHER>, stopwords for
@@ -267,14 +327,6 @@ L<Dist::Zilla::MintingProfile::Author::ETHER>
 
 =back
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-Author-ETHER>
-(or L<bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org|mailto:bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 NAMING SCHEME
 
 =for stopwords KENTNL
@@ -282,6 +334,19 @@ I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 This distribution follows best practices for author-oriented plugin bundles; for more information,
 see L<KENTNL's distribution|Dist::Zilla::PluginBundle::Author::KENTNL/NAMING-SCHEME>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-Author-ETHER>
+(or L<bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org|mailto:bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+http://dzil.org/#mailing-list.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
